#!/bin/ksh
###
# Suggested template for a root script to shutdown all DB2 operations as part of a server shutdown.
# This script reuses the comprehensive shutdown code in the $INSTHOME/dbascript maintenance libraries 
# to cover database deactivation, DB2 services and utilities.
# Alex, 13.07.2006 
###

if [[ $LOGIN == "root" ]]
then :
else
   print "$0 only executable from root. So sorry."
   exit 1 
fi 
 
LOG=/tmp/rc.db2_stop.log.$(date +%Y%m%d%H%M)
exec 2>&1
exec 1> $LOG                                # redirect stdout and stderr to a timestamped logfile 
print  $0                                   # display script name
DB2LIB=/usr/opt/db2_08_01/bin               # V8.x path; modify for alternate FixPacks.
typeset -i wordlength                       # 32 or 64 bit

for INSTANCE in `${DB2LIB}/db2ilist | sort` # execute each instance's DB2 shutdown script 
                                            # located in its $INSTHOME/dbascripts maintenance library.
do
    print "\n** Stopping DB2 at instance: \"${INSTANCE}\" **"
    su - ${INSTANCE} -c "/home/${INSTANCE}/dbascripts/db2_shutdown.ksh"
done

# Now stop the Database Administration Server; it's either 64 or 32 bit and there's only normally 1 DAS per server. 
# Unfortunately the presence of a 64 bit library does not mean the DAS is 64 bit.
# Assume all instances are at the same wordlength and get the bittage from the db2level command.
# Root cannot execute db2level directly, without setting DB2INSTANCE environment variable, hence the su to the last instance.

eval wordlength=$(su - ${INSTANCE} -c "db2level" | grep bits | awk '{print $5}' | tr -d '\042\')
case $wordlength in
     32) DASLIB=/usr/opt/db2_08_01/das/bin   ;;
     64) DASLIB=/usr/opt/db2_08_01/das/bin64 ;;
     * ) print "\n Unknown wordlength $wordlength ..."
         print "Script relies on DB2 V8.* db2level output and will require amendment at later releases.\n"
         exit 2 ;;
esac

for DAS in `${DASLIB}/db2dascfg get dasusr`
do
    print "\n** Stopping DB2 Administration Server (DAS): \"${DAS}\" **"
    su - ${DAS} -c "db2admin stop"
done

exec 1>&-      # restore stdout and stderr to previous settings
exec 1>&2

cat $LOG       # display results and
chmod 444 $LOG # make readable to instance owner/ support.
